OAuthError class

OAuth error response

Annotations
  • @immutable

Constructors

OAuthError({required String error, String? errorDescription, String? errorUri})
const
OAuthError.fromJson(Map<String, dynamic> json)
factory

Properties

error String
Error code
final
errorDescription String?
Human-readable error description
final
errorUri String?
URI for more information
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited