ModelPreferences class
Model preferences for sampling
- Annotations
-
- @immutable
Constructors
-
ModelPreferences({List<
ModelHint> ? hints, double? costPriority, double? speedPriority, double? intelligencePriority}) -
const
-
ModelPreferences.fromJson(Map<
String, dynamic> json) -
factory
Properties
- costPriority → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hints
→ List<
ModelHint> ? -
final
- intelligencePriority → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speedPriority → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited